@@ -1,9 +1,9 @@
 #
-# $Id: Factor.pm,v 0.09 2004/01/12 23:59:45 sts Exp $
+# $Id: Factor.pm,v 0.1 2004/01/12 10:17:06 sts Exp $
 
 package Math::Factor;
 
-our $VERSION = '0.09';
+our $VERSION = '0.1';
 
 use integer;
 use strict 'vars';
@@ -76,13 +76,14 @@ Ranges may be evaluated by providing a two-dimensional array.
 
  @numbers = (
      [ 9, '1-6' ],
+     [ 1032, '1-$' ],
      [ 30107, '*' ],
  );
 
 The first item (9) represents the number itself. The second item (1-6) represents
 the range that is being evaluated; ranges are indicated by a starting and ending
-value separated by a colon. Evaluating ranges for certain numbers may be entirely
-disabled by supplying *.
+value separated by a colon. $ indicates the number. Evaluating ranges for 
+certain numbers may be entirely disabled by supplying *. 1-$ is equivalent to *.
 
 =cut
 
@@ -99,7 +100,7 @@ sub factor {
 	    if ($$_[1] =~ /-/) { 
     	        my @range = split /-/, $$_[1];
 		$i = $range[0];
-		if ($range[1] eq '*') { $limit = $number } 
+		if ($range[1] eq '$') { $limit = $number } 
 		else { $limit = $range[1] }
 	    }
 	    else { $limit = $number } 
